/*
 * Copyright (C) 2011 Atmark Techno, Inc. All Rights Reserved.
 */

/*
 * The code contained herein is licensed under the GNU General Public
 * License. You may obtain a copy of the GNU General Public License
 * Version 2 or later at the following locations:
 *
 * http://www.opensource.org/licenses/gpl-license.html
 * http://www.gnu.org/copyleft/gpl.html
 */

#include <linux/platform_device.h>
#include <linux/gpio_keys.h>
#include <linux/input.h>
#include <mach/common.h>
#include "armadillo400_iomux.h"

static struct pad_desc armadillo400_gpio_keys_pads[] = {
	MX25_PAD_NFWP_B__GPIO_3_30(),

#if defined(CONFIG_MACH_ARMADILLO440)
	MX25_PAD_DE_B__GPIO_2_20(0), /* 47K_UP is always on */
#if defined(CONFIG_ARMADILLO400_CON11_40_GPIO_2_29)
	MX25_PAD_KPP_ROW0__GPIO_2_29(PAD_CTL_PKE | PAD_CTL_PUS_47K_UP),
#endif
#if defined(CONFIG_ARMADILLO400_CON11_41_GPIO_2_30)
	MX25_PAD_KPP_ROW1__GPIO_2_30(PAD_CTL_PKE | PAD_CTL_PUS_47K_UP),
#endif
#endif
};

static struct gpio_keys_button armadillo400_key_buttons[] = {
	{KEY_ENTER, GPIO(3, 30), 1, "SW1",     EV_KEY, 1},
#if defined(CONFIG_MACH_ARMADILLO440)
	{KEY_BACK,  GPIO(2, 20), 1, "LCD_SW1", EV_KEY, 1},
#endif
#if defined(CONFIG_ARMADILLO400_CON11_40_GPIO_2_29)
	{KEY_MENU,  GPIO(2, 29), 1, "LCD_SW2", EV_KEY, 1},
#endif
#if defined(CONFIG_ARMADILLO400_CON11_41_GPIO_2_30)
	{KEY_HOME,  GPIO(2, 30), 1, "LCD_SW3", EV_KEY, 1},
#endif
};

static struct gpio_keys_platform_data armadillo400_gpio_key_data = {
	.buttons = armadillo400_key_buttons,
	.nbuttons = ARRAY_SIZE(armadillo400_key_buttons),
	.rep = 1,
#if !defined(CONFIG_ARMADILLO400_GPIO_KEYS_WAKE_SRC_SELECT)
	.wakeup_default_disabled = 1,
#endif
};

static struct platform_device armadillo400_gpio_key_device = {
	.name ="gpio-keys",
	.id = 0,
};

void __init armadillo400_key_init(void)
{
	mxc_iomux_v3a_setup_multiple_pads(armadillo400_gpio_keys_pads);
	mxc_register_device(&armadillo400_gpio_key_device,
			    &armadillo400_gpio_key_data);
}
